``` bash
aea generate-key fetchai
aea add-key fetchai fetchai_private_key.txt
```
``` bash
aea generate-key ethereum
aea add-key ethereum ethereum_private_key.txt
```
``` bash
aea get-address fetchai
``` 
``` bash
aea get-address ethereum
```
``` bash
aea get-wealth fetchai
```
``` bash
aea get-wealth ethereum
```
``` bash
aea generate-wealth fetchai
```
``` bash
aea generate-wealth ethereum
```
